@@ -16,8 +16,9 @@ async def delete(
         success_codes = [200]
     if not headers:
         headers = {}
+    if not headers.get("content-type"):
+        headers["content-type"] = "application/json"
 
-    headers["content-type"] = "application/json"
     async with await hub.tool.request.session.delete(
         ctx, url=url, headers=headers, **kwargs
     ) as response:
@@ -25,11 +26,12 @@ async def delete(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Delete error: {(await response.read()).decode().strip()}")
+            hub.log.debug("Delete error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
@@ -47,7 +49,8 @@ async def get(
         success_codes = [200]
     if not headers:
         headers = {}
-    headers["content-type"] = "application/json"
+    if not headers.get("content-type"):
+        headers["content-type"] = "application/json"
 
     async with await hub.tool.request.session.get(
         ctx, url=url, headers=headers, **kwargs
@@ -56,11 +59,12 @@ async def get(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Get error: {(await response.read()).decode().strip()}")
+            hub.log.debug("Get error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
@@ -78,8 +82,9 @@ async def head(
         success_codes = [200]
     if not headers:
         headers = {}
+    if not headers.get("content-type"):
+        headers["content-type"] = "application/json"
 
-    headers["content-type"] = "application/json"
     async with await hub.tool.request.session.head(
         ctx, url=url, headers=headers, **kwargs
     ) as response:
@@ -87,11 +92,12 @@ async def head(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Head error: {(await response.read()).decode().strip()}")
+            hub.log.debug("Head error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
@@ -110,7 +116,9 @@ async def patch(
     if not headers:
         headers = {}
 
-    headers["content-type"] = "application/json"
+    if not headers.get("content-type"):
+        headers["content-type"] = "application/json"
+
     async with await hub.tool.request.session.patch(
         ctx, url=url, headers=headers, **kwargs
     ) as response:
@@ -118,11 +126,12 @@ async def patch(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Patch error: {(await response.read()).decode().strip()}")
+            hub.log.debug("Patch error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
@@ -140,7 +149,9 @@ async def post(
         success_codes = [200]
     if not headers:
         headers = {}
-    headers["content-type"] = "application/json"
+    if not headers.get("content-type"):
+        headers["content-type"] = "application/json"
+
     async with await hub.tool.request.session.post(
         ctx, url=url, headers=headers, **kwargs
     ) as response:
@@ -148,11 +159,12 @@ async def post(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Post error: {(await response.read()).decode().strip()}")
+            hub.log.debug("Post error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
@@ -179,11 +191,12 @@ async def put(
         if success:
             ret = hub.tool.type.dict.namespaced(await response.json())
         else:
-            hub.log.debug(f"Put error: {await response.read()}")
+            hub.log.debug("Put error: {}".format(await response.read()).strip())
             ret = {}
         return {
             "ret": ret,
             "status": success,
+            "status_code": response.status,
             "comment": response.reason,
             "headers": response.headers,
         }
